# Project support

* Nikos Tsardakas Renhult helped fixing an unfortunate color choice. He also fixed bugs in
  --dotted mode, and contributed options --only-variable and --only-variable-excluding-indels.
* Karin Lagesen @karinlag and Juan Villada @juanvillada had constructive suggestions when reviewing
  the paper for JOSS.
* @katieemalianova help chase down installation issues.
* @SimonGreenhill added support for the Nexus format.
* Roey Angel reported bug about `alv` not guessing the MSA type correctly when a DNA/RNA sequence is
  completely without "codons".
